# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorPerShareStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'share_prefix': 'str',
        'share_id': 'str',
        'local_path': 'str',
        'total_requests': 'int',
        'successful_requests': 'int',
        'failed_requests': 'int',
        'bytes_sent': 'int',
        'bytes_received': 'int',
        'share_start_time': 'datetime'
    }

    attribute_map = {
        'share_prefix': 'share_prefix',
        'share_id': 'share_id',
        'local_path': 'local_path',
        'total_requests': 'total_requests',
        'successful_requests': 'successful_requests',
        'failed_requests': 'failed_requests',
        'bytes_sent': 'bytes_sent',
        'bytes_received': 'bytes_received',
        'share_start_time': 'share_start_time'
    }

    def __init__(self, share_prefix=None, share_id=None, local_path=None, total_requests=None, successful_requests=None, failed_requests=None, bytes_sent=None, bytes_received=None, share_start_time=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorPerShareStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._share_prefix = None
        self._share_id = None
        self._local_path = None
        self._total_requests = None
        self._successful_requests = None
        self._failed_requests = None
        self._bytes_sent = None
        self._bytes_received = None
        self._share_start_time = None
        self.discriminator = None

        self.share_prefix = share_prefix
        self.share_id = share_id
        self.local_path = local_path
        self.total_requests = total_requests
        self.successful_requests = successful_requests
        self.failed_requests = failed_requests
        self.bytes_sent = bytes_sent
        self.bytes_received = bytes_received
        self.share_start_time = share_start_time

    @property
    def share_prefix(self):
        """Gets the share_prefix of this AgentConnectorPerShareStats.  # noqa: E501

        The prefix used to route the requests to the shared local path. This is typically derived from the share_name of the Share.   # noqa: E501

        :return: The share_prefix of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._share_prefix

    @share_prefix.setter
    def share_prefix(self, share_prefix):
        """Sets the share_prefix of this AgentConnectorPerShareStats.

        The prefix used to route the requests to the shared local path. This is typically derived from the share_name of the Share.   # noqa: E501

        :param share_prefix: The share_prefix of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_prefix is None:  # noqa: E501
            raise ValueError("Invalid value for `share_prefix`, must not be `None`")  # noqa: E501

        self._share_prefix = share_prefix

    @property
    def share_id(self):
        """Gets the share_id of this AgentConnectorPerShareStats.  # noqa: E501

        The unique ID of the FileShareService to which this share corresponds.   # noqa: E501

        :return: The share_id of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        """Sets the share_id of this AgentConnectorPerShareStats.

        The unique ID of the FileShareService to which this share corresponds.   # noqa: E501

        :param share_id: The share_id of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_id is None:  # noqa: E501
            raise ValueError("Invalid value for `share_id`, must not be `None`")  # noqa: E501

        self._share_id = share_id

    @property
    def local_path(self):
        """Gets the local_path of this AgentConnectorPerShareStats.  # noqa: E501

        The path on the local file system which is being shared.  # noqa: E501

        :return: The local_path of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._local_path

    @local_path.setter
    def local_path(self, local_path):
        """Sets the local_path of this AgentConnectorPerShareStats.

        The path on the local file system which is being shared.  # noqa: E501

        :param local_path: The local_path of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and local_path is None:  # noqa: E501
            raise ValueError("Invalid value for `local_path`, must not be `None`")  # noqa: E501

        self._local_path = local_path

    @property
    def total_requests(self):
        """Gets the total_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests made to this share.  # noqa: E501

        :return: The total_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._total_requests

    @total_requests.setter
    def total_requests(self, total_requests):
        """Sets the total_requests of this AgentConnectorPerShareStats.

        The total number of requests made to this share.  # noqa: E501

        :param total_requests: The total_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `total_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                total_requests is not None and total_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `total_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_requests = total_requests

    @property
    def successful_requests(self):
        """Gets the successful_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests which have succeeded.  # noqa: E501

        :return: The successful_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._successful_requests

    @successful_requests.setter
    def successful_requests(self, successful_requests):
        """Sets the successful_requests of this AgentConnectorPerShareStats.

        The total number of requests which have succeeded.  # noqa: E501

        :param successful_requests: The successful_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and successful_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `successful_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                successful_requests is not None and successful_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `successful_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._successful_requests = successful_requests

    @property
    def failed_requests(self):
        """Gets the failed_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests which have failed.  # noqa: E501

        :return: The failed_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._failed_requests

    @failed_requests.setter
    def failed_requests(self, failed_requests):
        """Sets the failed_requests of this AgentConnectorPerShareStats.

        The total number of requests which have failed.  # noqa: E501

        :param failed_requests: The failed_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_requests is not None and failed_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_requests = failed_requests

    @property
    def bytes_sent(self):
        """Gets the bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of bytes sent in the body of responses to requests. This includes any metadata about files, or data included in failure responses.   # noqa: E501

        :return: The bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_sent

    @bytes_sent.setter
    def bytes_sent(self, bytes_sent):
        """Sets the bytes_sent of this AgentConnectorPerShareStats.

        The total number of bytes sent in the body of responses to requests. This includes any metadata about files, or data included in failure responses.   # noqa: E501

        :param bytes_sent: The bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bytes_sent is None:  # noqa: E501
            raise ValueError("Invalid value for `bytes_sent`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bytes_sent is not None and bytes_sent < 0):  # noqa: E501
            raise ValueError("Invalid value for `bytes_sent`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_sent = bytes_sent

    @property
    def bytes_received(self):
        """Gets the bytes_received of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of bytes received in the body of requests. This includes any metadata about files, files themselves, or general commands such as lock requests.   # noqa: E501

        :return: The bytes_received of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_received

    @bytes_received.setter
    def bytes_received(self, bytes_received):
        """Sets the bytes_received of this AgentConnectorPerShareStats.

        The total number of bytes received in the body of requests. This includes any metadata about files, files themselves, or general commands such as lock requests.   # noqa: E501

        :param bytes_received: The bytes_received of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bytes_received is None:  # noqa: E501
            raise ValueError("Invalid value for `bytes_received`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bytes_received is not None and bytes_received < 0):  # noqa: E501
            raise ValueError("Invalid value for `bytes_received`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_received = bytes_received

    @property
    def share_start_time(self):
        """Gets the share_start_time of this AgentConnectorPerShareStats.  # noqa: E501

        When the share was started.  # noqa: E501

        :return: The share_start_time of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._share_start_time

    @share_start_time.setter
    def share_start_time(self, share_start_time):
        """Sets the share_start_time of this AgentConnectorPerShareStats.

        When the share was started.  # noqa: E501

        :param share_start_time: The share_start_time of this AgentConnectorPerShareStats.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and share_start_time is None:  # noqa: E501
            raise ValueError("Invalid value for `share_start_time`, must not be `None`")  # noqa: E501

        self._share_start_time = share_start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorPerShareStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorPerShareStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class LoginSession(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'session_id': 'str',
        'number_of_logins': 'int',
        'number_of_failed_multi_factor_challenges': 'int',
        'single_sign_on_time': 'datetime',
        'user_is_authenticated': 'bool',
        'user_is_authenticated_by_upstream': 'bool',
        'user_is_authenticated_by_cache': 'bool'
    }

    attribute_map = {
        'session_id': 'session_id',
        'number_of_logins': 'number_of_logins',
        'number_of_failed_multi_factor_challenges': 'number_of_failed_multi_factor_challenges',
        'single_sign_on_time': 'single_sign_on_time',
        'user_is_authenticated': 'user_is_authenticated',
        'user_is_authenticated_by_upstream': 'user_is_authenticated_by_upstream',
        'user_is_authenticated_by_cache': 'user_is_authenticated_by_cache'
    }

    def __init__(self, session_id=None, number_of_logins=None, number_of_failed_multi_factor_challenges=None, single_sign_on_time=None, user_is_authenticated=False, user_is_authenticated_by_upstream=False, user_is_authenticated_by_cache=False, local_vars_configuration=None):  # noqa: E501
        """LoginSession - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._session_id = None
        self._number_of_logins = None
        self._number_of_failed_multi_factor_challenges = None
        self._single_sign_on_time = None
        self._user_is_authenticated = None
        self._user_is_authenticated_by_upstream = None
        self._user_is_authenticated_by_cache = None
        self.discriminator = None

        self.session_id = session_id
        self.number_of_logins = number_of_logins
        self.number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges
        self.single_sign_on_time = single_sign_on_time
        self.user_is_authenticated = user_is_authenticated
        self.user_is_authenticated_by_upstream = user_is_authenticated_by_upstream
        self.user_is_authenticated_by_cache = user_is_authenticated_by_cache

    @property
    def session_id(self):
        """Gets the session_id of this LoginSession.  # noqa: E501

        The id of the session.  # noqa: E501

        :return: The session_id of this LoginSession.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this LoginSession.

        The id of the session.  # noqa: E501

        :param session_id: The session_id of this LoginSession.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and session_id is None:  # noqa: E501
            raise ValueError("Invalid value for `session_id`, must not be `None`")  # noqa: E501

        self._session_id = session_id

    @property
    def number_of_logins(self):
        """Gets the number_of_logins of this LoginSession.  # noqa: E501

        The number of logins that have occured with this session id  # noqa: E501

        :return: The number_of_logins of this LoginSession.  # noqa: E501
        :rtype: int
        """
        return self._number_of_logins

    @number_of_logins.setter
    def number_of_logins(self, number_of_logins):
        """Sets the number_of_logins of this LoginSession.

        The number of logins that have occured with this session id  # noqa: E501

        :param number_of_logins: The number_of_logins of this LoginSession.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and number_of_logins is None:  # noqa: E501
            raise ValueError("Invalid value for `number_of_logins`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_of_logins is not None and number_of_logins < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_logins`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_logins = number_of_logins

    @property
    def number_of_failed_multi_factor_challenges(self):
        """Gets the number_of_failed_multi_factor_challenges of this LoginSession.  # noqa: E501

        The number of failed multi-factor authentication challenges that have occured with this session id  # noqa: E501

        :return: The number_of_failed_multi_factor_challenges of this LoginSession.  # noqa: E501
        :rtype: int
        """
        return self._number_of_failed_multi_factor_challenges

    @number_of_failed_multi_factor_challenges.setter
    def number_of_failed_multi_factor_challenges(self, number_of_failed_multi_factor_challenges):
        """Sets the number_of_failed_multi_factor_challenges of this LoginSession.

        The number of failed multi-factor authentication challenges that have occured with this session id  # noqa: E501

        :param number_of_failed_multi_factor_challenges: The number_of_failed_multi_factor_challenges of this LoginSession.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and number_of_failed_multi_factor_challenges is None:  # noqa: E501
            raise ValueError("Invalid value for `number_of_failed_multi_factor_challenges`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                number_of_failed_multi_factor_challenges is not None and number_of_failed_multi_factor_challenges < 0):  # noqa: E501
            raise ValueError("Invalid value for `number_of_failed_multi_factor_challenges`, must be a value greater than or equal to `0`")  # noqa: E501

        self._number_of_failed_multi_factor_challenges = number_of_failed_multi_factor_challenges

    @property
    def single_sign_on_time(self):
        """Gets the single_sign_on_time of this LoginSession.  # noqa: E501

        The time of the user's last login with an upstream identity provider if the policy supported single sign on.  # noqa: E501

        :return: The single_sign_on_time of this LoginSession.  # noqa: E501
        :rtype: datetime
        """
        return self._single_sign_on_time

    @single_sign_on_time.setter
    def single_sign_on_time(self, single_sign_on_time):
        """Sets the single_sign_on_time of this LoginSession.

        The time of the user's last login with an upstream identity provider if the policy supported single sign on.  # noqa: E501

        :param single_sign_on_time: The single_sign_on_time of this LoginSession.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and single_sign_on_time is None:  # noqa: E501
            raise ValueError("Invalid value for `single_sign_on_time`, must not be `None`")  # noqa: E501

        self._single_sign_on_time = single_sign_on_time

    @property
    def user_is_authenticated(self):
        """Gets the user_is_authenticated of this LoginSession.  # noqa: E501

        An aggregate condition representing the user's authentication status in the session. This field is the result of user_is_authenticated_by_upstream OR'd with user_is_authenticated_by_cache   # noqa: E501

        :return: The user_is_authenticated of this LoginSession.  # noqa: E501
        :rtype: bool
        """
        return self._user_is_authenticated

    @user_is_authenticated.setter
    def user_is_authenticated(self, user_is_authenticated):
        """Sets the user_is_authenticated of this LoginSession.

        An aggregate condition representing the user's authentication status in the session. This field is the result of user_is_authenticated_by_upstream OR'd with user_is_authenticated_by_cache   # noqa: E501

        :param user_is_authenticated: The user_is_authenticated of this LoginSession.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and user_is_authenticated is None:  # noqa: E501
            raise ValueError("Invalid value for `user_is_authenticated`, must not be `None`")  # noqa: E501

        self._user_is_authenticated = user_is_authenticated

    @property
    def user_is_authenticated_by_upstream(self):
        """Gets the user_is_authenticated_by_upstream of this LoginSession.  # noqa: E501

        Indicates whether the user has been directly authenticated by an upstream identity provider  # noqa: E501

        :return: The user_is_authenticated_by_upstream of this LoginSession.  # noqa: E501
        :rtype: bool
        """
        return self._user_is_authenticated_by_upstream

    @user_is_authenticated_by_upstream.setter
    def user_is_authenticated_by_upstream(self, user_is_authenticated_by_upstream):
        """Sets the user_is_authenticated_by_upstream of this LoginSession.

        Indicates whether the user has been directly authenticated by an upstream identity provider  # noqa: E501

        :param user_is_authenticated_by_upstream: The user_is_authenticated_by_upstream of this LoginSession.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and user_is_authenticated_by_upstream is None:  # noqa: E501
            raise ValueError("Invalid value for `user_is_authenticated_by_upstream`, must not be `None`")  # noqa: E501

        self._user_is_authenticated_by_upstream = user_is_authenticated_by_upstream

    @property
    def user_is_authenticated_by_cache(self):
        """Gets the user_is_authenticated_by_cache of this LoginSession.  # noqa: E501

        Indicates whether the user has been authenticated via a cached credential  # noqa: E501

        :return: The user_is_authenticated_by_cache of this LoginSession.  # noqa: E501
        :rtype: bool
        """
        return self._user_is_authenticated_by_cache

    @user_is_authenticated_by_cache.setter
    def user_is_authenticated_by_cache(self, user_is_authenticated_by_cache):
        """Sets the user_is_authenticated_by_cache of this LoginSession.

        Indicates whether the user has been authenticated via a cached credential  # noqa: E501

        :param user_is_authenticated_by_cache: The user_is_authenticated_by_cache of this LoginSession.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and user_is_authenticated_by_cache is None:  # noqa: E501
            raise ValueError("Invalid value for `user_is_authenticated_by_cache`, must not be `None`")  # noqa: E501

        self._user_is_authenticated_by_cache = user_is_authenticated_by_cache

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoginSession):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoginSession):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus is API-first. Modern software is controlled by other software, is open, is available for you to use the way you want, securely, simply.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api). You may try the API inline directly in the web page. To do so, first obtain an Authentication Token (the simplest way is to install the Python SDK, and then run `agilicus-cli --issuer https://MYISSUER get-token`). You will need an org-id for most calls (and can obtain from `agilicus-cli --issuer https://MYISSUER list-orgs`). The `MYISSUER` will typically be `auth.MYDOMAIN`, and you will see it as you sign-in to the administrative UI.  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com.  If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.05.06
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Audit(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'target_resource_type': 'str',
        'api_name': 'str',
        'org_id': 'str',
        'time': 'datetime',
        'action': 'str',
        'source_ip': 'str',
        'target_id': 'str',
        'token_id': 'str',
        'trace_id': 'str',
        'session': 'str',
        'secondary_id': 'str',
        'tertiary_id': 'str',
        'parent_id': 'str',
        'grandparent_id': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'target_resource_type': 'target_resource_type',
        'api_name': 'api_name',
        'org_id': 'org_id',
        'time': 'time',
        'action': 'action',
        'source_ip': 'source_ip',
        'target_id': 'target_id',
        'token_id': 'token_id',
        'trace_id': 'trace_id',
        'session': 'session',
        'secondary_id': 'secondary_id',
        'tertiary_id': 'tertiary_id',
        'parent_id': 'parent_id',
        'grandparent_id': 'grandparent_id'
    }

    def __init__(self, user_id=None, target_resource_type=None, api_name=None, org_id=None, time=None, action=None, source_ip=None, target_id=None, token_id=None, trace_id=None, session=None, secondary_id=None, tertiary_id=None, parent_id=None, grandparent_id=None, local_vars_configuration=None):  # noqa: E501
        """Audit - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._target_resource_type = None
        self._api_name = None
        self._org_id = None
        self._time = None
        self._action = None
        self._source_ip = None
        self._target_id = None
        self._token_id = None
        self._trace_id = None
        self._session = None
        self._secondary_id = None
        self._tertiary_id = None
        self._parent_id = None
        self._grandparent_id = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if target_resource_type is not None:
            self.target_resource_type = target_resource_type
        if api_name is not None:
            self.api_name = api_name
        if org_id is not None:
            self.org_id = org_id
        if time is not None:
            self.time = time
        if action is not None:
            self.action = action
        if source_ip is not None:
            self.source_ip = source_ip
        if target_id is not None:
            self.target_id = target_id
        if token_id is not None:
            self.token_id = token_id
        if trace_id is not None:
            self.trace_id = trace_id
        if session is not None:
            self.session = session
        if secondary_id is not None:
            self.secondary_id = secondary_id
        if tertiary_id is not None:
            self.tertiary_id = tertiary_id
        if parent_id is not None:
            self.parent_id = parent_id
        if grandparent_id is not None:
            self.grandparent_id = grandparent_id

    @property
    def user_id(self):
        """Gets the user_id of this Audit.  # noqa: E501

        The id of the user performing the action  # noqa: E501

        :return: The user_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Audit.

        The id of the user performing the action  # noqa: E501

        :param user_id: The user_id of this Audit.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def target_resource_type(self):
        """Gets the target_resource_type of this Audit.  # noqa: E501

        The name of the resource type which was affected by the event which generated this record. The `target_id` field will uniquely identify, if possible, the record within the resource type.   # noqa: E501

        :return: The target_resource_type of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._target_resource_type

    @target_resource_type.setter
    def target_resource_type(self, target_resource_type):
        """Sets the target_resource_type of this Audit.

        The name of the resource type which was affected by the event which generated this record. The `target_id` field will uniquely identify, if possible, the record within the resource type.   # noqa: E501

        :param target_resource_type: The target_resource_type of this Audit.  # noqa: E501
        :type: str
        """

        self._target_resource_type = target_resource_type

    @property
    def api_name(self):
        """Gets the api_name of this Audit.  # noqa: E501

        The name of the API which generated the event. This will typically be a single value for many different target_resource_types.   # noqa: E501

        :return: The api_name of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._api_name

    @api_name.setter
    def api_name(self, api_name):
        """Sets the api_name of this Audit.

        The name of the API which generated the event. This will typically be a single value for many different target_resource_types.   # noqa: E501

        :param api_name: The api_name of this Audit.  # noqa: E501
        :type: str
        """

        self._api_name = api_name

    @property
    def org_id(self):
        """Gets the org_id of this Audit.  # noqa: E501

        The organization of the user performing the action  # noqa: E501

        :return: The org_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this Audit.

        The organization of the user performing the action  # noqa: E501

        :param org_id: The org_id of this Audit.  # noqa: E501
        :type: str
        """

        self._org_id = org_id

    @property
    def time(self):
        """Gets the time of this Audit.  # noqa: E501

        the time at which the log was generated  # noqa: E501

        :return: The time of this Audit.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this Audit.

        the time at which the log was generated  # noqa: E501

        :param time: The time of this Audit.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def action(self):
        """Gets the action of this Audit.  # noqa: E501

        The type of action performed on the target  # noqa: E501

        :return: The action of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this Audit.

        The type of action performed on the target  # noqa: E501

        :param action: The action of this Audit.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def source_ip(self):
        """Gets the source_ip of this Audit.  # noqa: E501

        The IP address of the host initating the action  # noqa: E501

        :return: The source_ip of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._source_ip

    @source_ip.setter
    def source_ip(self, source_ip):
        """Sets the source_ip of this Audit.

        The IP address of the host initating the action  # noqa: E501

        :param source_ip: The source_ip of this Audit.  # noqa: E501
        :type: str
        """

        self._source_ip = source_ip

    @property
    def target_id(self):
        """Gets the target_id of this Audit.  # noqa: E501

        The id of the resource affected by the action  # noqa: E501

        :return: The target_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this Audit.

        The id of the resource affected by the action  # noqa: E501

        :param target_id: The target_id of this Audit.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def token_id(self):
        """Gets the token_id of this Audit.  # noqa: E501

        The id of the bearer token used to authenticate when performing the action  # noqa: E501

        :return: The token_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this Audit.

        The id of the bearer token used to authenticate when performing the action  # noqa: E501

        :param token_id: The token_id of this Audit.  # noqa: E501
        :type: str
        """

        self._token_id = token_id

    @property
    def trace_id(self):
        """Gets the trace_id of this Audit.  # noqa: E501

        A correlation ID associated with requests related to this action  # noqa: E501

        :return: The trace_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this Audit.

        A correlation ID associated with requests related to this action  # noqa: E501

        :param trace_id: The trace_id of this Audit.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def session(self):
        """Gets the session of this Audit.  # noqa: E501

        The session associated with this action. Sessions typically span multiple tokens.   # noqa: E501

        :return: The session of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this Audit.

        The session associated with this action. Sessions typically span multiple tokens.   # noqa: E501

        :param session: The session of this Audit.  # noqa: E501
        :type: str
        """

        self._session = session

    @property
    def secondary_id(self):
        """Gets the secondary_id of this Audit.  # noqa: E501

        The secondary id of the resource affected by the action if one exists. This can occur if the resource's primary key is a composite key. APIs whose resources are not referenced by a GUID in the path make use of these fields for example the replace_user_role endpoint uses the user_id, and application to identify a resource.   # noqa: E501

        :return: The secondary_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._secondary_id

    @secondary_id.setter
    def secondary_id(self, secondary_id):
        """Sets the secondary_id of this Audit.

        The secondary id of the resource affected by the action if one exists. This can occur if the resource's primary key is a composite key. APIs whose resources are not referenced by a GUID in the path make use of these fields for example the replace_user_role endpoint uses the user_id, and application to identify a resource.   # noqa: E501

        :param secondary_id: The secondary_id of this Audit.  # noqa: E501
        :type: str
        """

        self._secondary_id = secondary_id

    @property
    def tertiary_id(self):
        """Gets the tertiary_id of this Audit.  # noqa: E501

        The tertiary id of the resource affected by the action if one exists. This can occur if the resource's primary key is a composite key.   # noqa: E501

        :return: The tertiary_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._tertiary_id

    @tertiary_id.setter
    def tertiary_id(self, tertiary_id):
        """Sets the tertiary_id of this Audit.

        The tertiary id of the resource affected by the action if one exists. This can occur if the resource's primary key is a composite key.   # noqa: E501

        :param tertiary_id: The tertiary_id of this Audit.  # noqa: E501
        :type: str
        """

        self._tertiary_id = tertiary_id

    @property
    def parent_id(self):
        """Gets the parent_id of this Audit.  # noqa: E501

        The id of the parent resource for the resource affected by the action. An example of this is the path /v1/collection/2jkdcmwB97jh3kiglnz/subcollection/idabc123. The resource belongs to the `subcollection` which falls under the parent in this case `collection`. As a resulti idabc123 is the target_id, 2jkdCmwB9u7Jh3KIglNZ is the parent ID   # noqa: E501

        :return: The parent_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Audit.

        The id of the parent resource for the resource affected by the action. An example of this is the path /v1/collection/2jkdcmwB97jh3kiglnz/subcollection/idabc123. The resource belongs to the `subcollection` which falls under the parent in this case `collection`. As a resulti idabc123 is the target_id, 2jkdCmwB9u7Jh3KIglNZ is the parent ID   # noqa: E501

        :param parent_id: The parent_id of this Audit.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def grandparent_id(self):
        """Gets the grandparent_id of this Audit.  # noqa: E501

        The id of the grandparent resource for the resource affected by the action. An example of this is the path /v1/collection/2jkdcmwB97jh3kiglnz/subcollection/2334115135/subsubcolletion/aaabbbccc Similar to the parent id example  aaabbbccc is the target_id, 2334115135 is the parent ID and 2jkdcmwB97jh3kiglnz is the grandparent_id   # noqa: E501

        :return: The grandparent_id of this Audit.  # noqa: E501
        :rtype: str
        """
        return self._grandparent_id

    @grandparent_id.setter
    def grandparent_id(self, grandparent_id):
        """Sets the grandparent_id of this Audit.

        The id of the grandparent resource for the resource affected by the action. An example of this is the path /v1/collection/2jkdcmwB97jh3kiglnz/subcollection/2334115135/subsubcolletion/aaabbbccc Similar to the parent id example  aaabbbccc is the target_id, 2334115135 is the parent ID and 2jkdcmwB97jh3kiglnz is the grandparent_id   # noqa: E501

        :param grandparent_id: The grandparent_id of this Audit.  # noqa: E501
        :type: str
        """

        self._grandparent_id = grandparent_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Audit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Audit):
            return True

        return self.to_dict() != other.to_dict()
